
globals[
  
  ;;; METRICS
  ;; Primary
  collective-position               ;; the mean individual-position of all agents  
  Spread-of-individual-positions   ;; the standard deviation of the agent individual-positions from the mean (collective position) at the end of the run
  decision-strategy-used            ;; One of three types of decision strategies occurs at the end of each run: whole-group convergence; point-person consensus; outside arbiter. This records which was chosen.
  ;; Other
  decision-OA                       ;; set to 1 if the decision strategy used was outside arbiter, otherwise 0 by default
  decision-PPC                      ;; set to 1 if the decision strategy used was point-person consensus, otherwise 0 by default
  decision-WGC                      ;; set to 1 if the decision strategy used was whole-group convergence, otherwise 0 by default
  number-of-mutations               ;; total number of times agents have mutated their individual-position values
  count-entrenched-at-start         ;; the number of agents entrenched at the start of the run
  count-entrenched-after-mutation   ;; the number of agents that became entrenched at the end of a run
  count-subject-to-CoD              ;; the total number of times any agents were subject to cost of dissent
  final-tick                        ;; length of the run - either 64 or smaller if whole-group consensus reached first
  total-number-of-interactions      ;; number of times there was an interaction
  sum-number-of-times-interacting   ;; the sum of number-of-times-interacting (a turtle variable), which is sum of the times all agents have interacted
  sum-flagged                       ;; the sum of the times any agent has been selected to possibly interact
  average-interactions-per-agent    ;; sum-number-of-times-interacting / Number-of-Agents
  final-decision                    ;; the numerical score that is the outcome - set based on the decision strategy used, so it is either the collective position of all the agents, the mean of the individual positions for the point persons, or one of the individual-position values of one of the point persons

  ;; USED IN PROCESSES 
  sample-position                 ;; a variable used to determine whether whole-group convergence has been reached
  sample-group-here                 ;; a variable used when checking for inter-group informal interactions
  group-counter-setup               ;; variable used only when setting up groups to keep track of the number of agents in a group
  maximum-iterations                ;; the tick on which the run ends (64 this setup)
  type-of-interaction               ;; the type of interaction being displayed in the landscape at that momemt.
]

breed [ point-persons point-person ]
breed [ advisors advisor ]

turtles-own [
  individual-position               ;; Represents intensity of desired action in relation to one specific issue. Ranges from 0 to 1. E.g. 0 represents take no action and 1 represents greatest possible level of action.
  position-future                   ;; Buffer layer for the new updated individual-position value. It becomes the individual-position after all agents have updated their own individual-positions
  ID                                ;; Unique identification number for turtle, corresponds to the x coordinate of the patch it is on
  inactive-color                    ;; the color of the agent if it is not interacting. the color darkens if it is interacting. colors are based on what group it belongs to.
  updating?                         ;; A flag to indicate the turtle was selected to interact witb other agents. if other conditions are met, it will interact.
  group                             ;; 0, 1, or 2; number that corresponds to the group to which it is assigned
  number-of-times-interacting       ;; the number of times that the turtle has interacted with other agents
  entrenched?                       ;; is the agent entrenched? yes/no
  ;; relating to cost of dissent
  Self-respect-reduction-CoD   ;; the maximum amount (on the final day of the run) that self-respect can be lowered in agents who are subject to cost of dissent. .2 for advisors and 1 for point-persons                               
  local-group-collective-position   ;; collective position of the local group excluding the calling agent
  local-group-SD                    ;; SD of local group excluding self
]

patches-own [
  respect                         ;; how much the agent in the row respects the agent on that column. on a scale of 0 to 1, where 1 = highest level and 0 = no respect.
  normalized-respect              ;; the respect value normalized based on the other agents with which the agent is interacting. on a scale of 0 to 1. n-r = r/sum of all r values the agent has for all interacting agents
  p-inactive-color                ;; the color of the patch if it is not active. the color darkens if it is interacting. colors are based on what group the agent in that row belongs to.
]


to setup
  ;; (for this model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  __clear-all-and-reset-ticks
  ;; resize world so that there is space for only one agent in each row or column (e.g. with 18 agents, it will be 18 x 18 cells)
  resize-world 0 ( Total-Number-of-Agents - 1 ) ( ( Total-Number-of-Agents - 1 ) * -1 ) 0
  set maximum-iterations 64  ;; will run for 64 days
  ;; create the agents and assign them to a place on the landscape
  create-agents
  ;; setup individual-position and respect scores
  setup-positions
  setup-respect
  ;; color the patches and turtles so they colors correspond to group memebrship
  do-colors
  reset-ticks
end



to create-agents
  ;; creating a turtle on each patch determing where the pxcor = the absolute value of the pycor
  foreach sort patches with [ pxcor = abs ( pycor ) ] [
    ask ? [
      if count turtles < Total-Number-of-Agents [
        sprout 1[
          set size .6
          set ID ( abs ( pxcor ) )
          set breed advisors ;; all agents start as advisors then in the next step are set to be point persons if conditions are met.
          set entrenched? false
          set updating? false
        ]
      ]
    ]
  ]
  
  ;; now setting up groups and point persons
  ;; we assume that there is only one point person per group
  
  ;; if random-sized groups are desired
  if Group-agent-distribution = "random-size" [
    ;; setting up a counter to keep track of group numbers
    set group-counter-setup 0
    ;; repeating for as many groups as there are only, since there is only one point person per group
    repeat Total-Number-of-Groups [
      ask one-of turtles with [ breed = advisors ] [
        set breed point-persons
        set shape "square" ;; different shape to indicate the point person
        set size 1
        set group group-counter-setup
  
      ]
      ;; advance the counter after a point person created
      set group-counter-setup ( group-counter-setup + 1 )
    ]
    
    ;; after the desired number of point persons are created to correspond to the number of groups, assign
    foreach sort-by [[ID] of ?1 < [ID] of ?2] turtles [
      ask ? [
        if breed = advisors
        [
          ;; joining the group of the closest point person
          set group [ group ] of min-one-of point-persons [distance myself]
          set shape "triangle"
        ]
      ]
    ]
  ]
  
  ;; or if equal-sized groups are desired
  if Group-agent-distribution = "equal-size-groups" [
    set group-counter-setup 0
    ;; the next variable is used when determining how many advisors will be in a given group. it is the number of agents minus the number of point persons (or groups, since there is one point person per groups)
    let number-available-minus-decision-makers ( Total-Number-of-Agents - Total-Number-of-Groups )
    
    repeat Total-Number-of-Groups [
      
      ;; the next variable is the agent with the lowest ID that has yet to be assigned. assigning groups and point persons starts in the upper left corner and works down to the right
      let min-ID min [ ID ] of turtles with [ shape = "default" ] ;; default shape means the agent has no group yet
      ask turtles with [ ID = min-ID ] ;; will be only 1 turtle. this one will be the point-person
      [
        set group group-counter-setup
        set breed point-persons
        set shape "square" ;; different shape to indicate the point person
      ]
      ;; now creating advisors for the point person's group.
      ;; calculating how many agents will be assigned advisors in this group, which is what num-in-group is. the ceiling primitive rounds up if there is not an interger. it is the number of agents who will ultimately be advisors but are not yet assigned a group / number of groups yet to be setup
      let num-in-group ceiling number-available-minus-decision-makers / ( Total-Number-of-Groups - group-counter-setup )
      ;; setting up a counter that is used to keep track of the number of advisors who have been assigned to the current group in the next foreach section
      let counter1 0
      foreach sort turtles with [ shape = "default" ] [
        ;; starting in the upper left corner, turns unassigned agents into advisors of the indicated group until the proper number of agents have been assigned to the group
        ask ? [ if counter1 < num-in-group
          [ set group group-counter-setup
            set breed advisors
            set shape "triangle"
            ;; adjusts the number of unassigned agents who will ultimately be advisors
            set number-available-minus-decision-makers number-available-minus-decision-makers - 1
          ]
        ;; advances the counter in advisors in the group
        set counter1 ( counter1 + 1 ) 
        ]
      ]
      ;; advance the group counter
      set group-counter-setup group-counter-setup + 1 
    ]
  ]
  
  ;; assigning colors to the agents based on group membership. these are the colors for when the agents are not actively interacting.
  ask turtles [
    if group = 0 [ set inactive-color 17 ] ;; light red
    if group = 1 [ set inactive-color 5 ] ;; light grey
    if group = 2 [ set inactive-color 87 ] ;; light cyan
    if group = 3 [ set inactive-color 47 ] ;; light yellow
  ]
  
  ;; setting variables that are specific to the breed of the turtle. 
  ;; point persons are less susceptible to being subject to cost of dissent, so their CoD-Base-Self-Respect-Reduction is much smaller than that of advisors
  ask point-persons [
    set Self-respect-reduction-CoD .2 
  ]
  ask advisors [
    set Self-respect-reduction-CoD 1
  ]
  
end


;;this procedure sets up the respect values that agents have for themselves and others
to setup-respect

  ;; if entrenchment is allowed, then have the mechanism go first before the regular method of setting respect
  if Entrenchment-possible? [
    entrench
  ]
  
  ask patches [          
    ask patches with [ respect = 0 ] [ ;; if the respect is 0, it means that it was not set by the entrench procedure
      ;; assigning a random number between 0 and 1
      set respect ( random-float 1 )
    ]
  ]
  
  
  ask patches [
    ;; setting up the labels and display of the patches
    set plabel-color magenta
    set plabel precision respect 3
    ;; the next line tells the patch what color it should be based on the group the agent in its row is in. The patch will have a slightly lighter color than the agents.
    set p-inactive-color ( sum [ inactive-color ] of turtles with [ id = [ abs pycor ] of myself ] ) + 2
  ]
  
end


to entrench
  ask turtles [
    let make-entrenched? false ;; used as a reference local variable. set by patches that represent self respect and used by patches that represent respect for others
    let reference-ID-here ID ;; local variable for the patch where the agent is (self-respect patch)
    ask patches with [ abs pxcor = reference-ID-here and abs pycor = reference-ID-here ] [
      ;; set self-respect first and if it is greater or equal to .9, then the agent is entrenched
      set respect ( random-float 1 )
      if respect >= .9 [
        set make-entrenched? true
        set count-entrenched-at-start count-entrenched-at-start + 1
      ]
    ]
    ;; so if the agent was entrenched, then all the respect for other agents is set to be .01 (not 0, otherwise the person would not really be involved in collective decision making)
    if make-entrenched? = true [
      set entrenched? true
      ask patches with [ abs pycor = reference-ID-here and abs pxcor != reference-ID-here ] [
        set respect .01
      ]
    ]
  ]
end


;;this procedure assigns an individual-position values for agents
to setup-positions

  ;; if random individual-positions are desired:  
  if Position-distribution = "random-uniform" [
    ask turtles [
      ;; number from 0 to 1
      set individual-position ( random-float 1 )
    ]
  ]
  
  ;; if intra-group polarization is desired (the people within each group are at odds- half in each group have an individual-position of 0 and half have 1)
  if Position-distribution = "intra-group-polarization" [
    let gcounter1 0
    repeat Total-Number-of-Groups [
      let half-turtles-group round ( count turtles with [ group = gcounter1 ] / 2 )
      ask n-of half-turtles-group turtles with [ group = gcounter1 ] [ set individual-position 1 ]
      ask turtles with [ group = gcounter1 ] [ if individual-position = 0 [ set individual-position 0 ] ]
      set gcounter1 ( gcounter1 + 1 )
    ]
  ]
  
  ;; if inter-group polarization is desired- this only works with 2 groups (the people in 1 group have individual-position of 1 and the other group 0)
  if Position-distribution = "inter-group-polarization" [
    ask turtles [
      if group = 0 [ set individual-position 1 ]
      if group = 1 [ set individual-position 0 ]
    ]
  ]
  
  ;; saving the collective individual-position value
  set collective-position mean [ individual-position ] of turtles
  
  ;; setting up the display of labels for the agents
  ask turtles [
    set label-color magenta
    set label precision individual-position 2
  ]
  
end


;; color the patches and agents
;; agents and patches not interacting have lighter color, but those actively interacting have a darker shade
to do-colors
  ask turtles with [ updating? = true ] [ set color inactive-color - 2]
  ask turtles with [ updating? = false ] [ set color inactive-color ]
  
  ;; patches only have a normalized-respect score not equal to 0 if they are interacting
  ask patches with [ normalized-respect != 0 ] [ set pcolor p-inactive-color - 2 ]
  ask patches with [ normalized-respect = 0 ] [ set pcolor p-inactive-color ]
end



to go

  ;; Checking to see id the run will end
  
  ;; first, checking for whole-group convergence
  ;; selecting one individual-position at random then seeing if all the other values are within .01 of each other
  if ( abs ( max [ individual-position ] of turtles - min [ individual-position ] of turtles ) ) <= .01 [
    ;; if convergence, then record the decision information and stop the run
    record-decision
    stop
  ]
  
  ;; second, if the time limit of the run is up, then make a decision and stop the run
  if ticks = maximum-iterations [
    make-decision
    stop
  ]   
  
  ;; Mechanisms
  
  ;; check for introduction of outside information
  mutation
  ;; check to see if there will be interactions, and if yes, update individual-positions
  Check-for-interaction
  ;; update graphs and global variables
  do-plots-and-globals
  ;; record the completion of an iteration
  tick
  
end

;; this records the decision strategy used and when the run stopped
to record-decision
  set final-decision sample-position
  set decision-strategy-used "whole-group convergence"
  set decision-WGC 1
  set final-tick ticks
end


to make-decision
  ;; there was no convergence, so it moves up to the point persons to try to decide.
  ;; the point persons interact then see if their individual-position are close enough as specified by the Point-person-position-difference-PPC slider
  
  ;; so first, the point persons interact. after flag-inter-group-formal runs, it automatically moves to interact from there.
  flag-inter-group-formal
  ;; if the difference between the minimum and maximum individual-positions of the point persons is within the Point-person-position-difference,
  ;; then it is classified as point person.
  ifelse ( abs ( max [ individual-position ] of point-persons - min [ individual-position ] of point-persons ) ) <= Point-person-position-difference-PPC [
    set final-decision mean [ individual-position ] of point-persons
    set decision-strategy-used "point-person consensus"
    set decision-PPC 1
  ]
  ;; but, if the point person individual-positions scores are still not close, the decision strategy is outside arbiter and the final decision is randomly selected from the point person individual-positions
  ;; this simulates that there was an outside force that randomly chose the decision (e.g. a board of directors)
  [
    let coin-flip random Total-Number-of-Groups
    ask one-of point-persons with [ group = coin-flip ] [
      set final-decision individual-position
      set decision-strategy-used "outside arbiter"
      set decision-OA 1
    ]
  ]
  
  ;; records the iteration the run ended
  set final-tick ticks
  
end


;; when external information causes an agent to change its individual-position, it is a mutation.
;; mutation rate is set by the Probability-of-mutation slider
;; after the agent receives new info, it gets a new self respect score to reflect how confident it is in the new information
;; if entrenchment is turned on, then entrenchment is possible now.
to mutation
  ;; every iteration, each agent checks for a mutation
  ask turtles [
    let random-mutation ( ( random 1000 ) + 1 )
    if random-mutation <= Probability-of-mutation [
      ;; if true, the individual-position will be randomly changed.
      set  individual-position ( random-float 1 )
      set number-of-mutations ( number-of-mutations + 1 )
      
      ;; calculating a new self-respect score
      let make-agent-entrenched-from-mutation? false
      set entrenched? false
      let mutation-reference-ID ID
      ask patch-here [
        set respect ( random-float 1 )
        
        ;; if entrenchment is turned on, then checking for entrenchment.
        if Entrenchment-possible? [
          if respect >= .9 [
            set make-agent-entrenched-from-mutation? true
            set count-entrenched-after-mutation count-entrenched-after-mutation + 1
          ]
        ]
      ]
      ;; then if the agent became entrenched, adjusting the respect for other agents
      if make-agent-entrenched-from-mutation? = true [
        set entrenched? true
        ask patches with [ abs pycor = mutation-reference-ID and abs pxcor != mutation-reference-ID ] [
          set respect .1
        ]
      ]
    ]
  ]
  
end

;; each iteration, the model checks for each of the 4 types of interactions
to Check-for-interaction
  
  ;; Inter-group interactions
  
  ;; these only happen if there are more than 1 groups
  if Total-Number-of-Groups > 1 [
    
    ;; Inter-group formal interaction
    ;; Interaction of all point persons
    ;; if the iteration number is a multiple of the spacing of this type of meeting (or the first iteration), then the formal meeting happens
    if Frequency-of-inter-group-formal-meetings != 0 [
      if ticks mod Frequency-of-inter-group-formal-meetings = 0 [
        flag-inter-group-formal
      ]
    ]
    
    ;; inter-group informal interaction
    ;; If agents from at least 2 different groups are selected to interact, then this meeting type happens
    flag-inter-group-informal
  ]
  
  ;; Intra-group interactions
  
  ;; Intra-group formal
  ;; formal meeting of all advisors and point persons in a group
  ;; if the iteration number is a multiple of the spacing of this type of meeting (or the first iteration), then the formal meeting happens
  if Frequency-of-intra-group-formal-meetings != 0 [
    if ticks mod Frequency-of-intra-group-formal-meetings = 0 [
      flag-intra-group-formal
    ]
  ]
  
  ;; Intra-group informal
  ;; Agents in the same group may interact
  flag-intra-group-informal
  
end


;; These next 4 procedures determines who will interact and then if conditions are right, then the interaction happens

to flag-inter-group-formal
  ;; Inter-group formal interaction
  ;; Interaction of all point persons
  ask point-persons [
    set updating? true
  ]
  set type-of-interaction "Inter-group Formal"
  interact
end


to flag-inter-group-informal
  ;; inter-group informal interaction
  ask turtles [
    ;; flagged to interact if chance1 <= Probability-inter-group-informal slider
    let chance1 ( ( random 100 ) + 1 )
    if chance1 <= ( (Probability-inter-group-informal-meetings * 2)/ 18 ) [
      set updating? true
    ]
  ]
  ;; If agents from at least 2 different groups are selected to interact, then this meeting type happens
  ;; setting a sample group of one of the agents selected to interact
  if any? turtles with [ updating? = true ] [ ask one-of turtles with [ updating? = true ] [ set sample-group-here group ] ]
  ;; if more than 1 agent flagged  
  ifelse count turtles with [ updating? = true ] > 1
    [
      ;; if there are no flagged agents with a group other than the sample group, then the interaction does not happen and the flagging is reset. otherwise, the interaction does happen
      ifelse all? turtles with [ updating? = true ] [ group = sample-group-here ] [
        ;; when the interaction does not happen
        set sum-flagged ( sum-flagged + ( count turtles with [ updating? = true ] ) )
        ask turtles with [ updating? = true ] [ set updating? false ]
      ]
      [
        ;; when the interaction does happen
        set type-of-interaction "Inter-group Informal"
        interact
      ]
    ]
    [
      ;; resets the flagging since the interaction didn't happen due to only 1 agent flagged
      set sum-flagged ( sum-flagged + ( count turtles with [ updating? = true ] ) )
      ask turtles with [ updating? = true ] [ set updating? false ]
    ]
end
  

to flag-intra-group-formal
  ;; Intra-group formal
  ;; formal meeting of all advisors and point persons in a group
  ;; using a counter to cycle through the groups
  let counter2 0
  repeat Total-Number-of-Groups [
    if count turtles with [ group = counter2 ] > 1 [
      ask turtles with [ group = counter2 ] [ set updating? true ]
      set type-of-interaction "Intra-group Formal"
      interact
    ]
    set counter2 counter2 + 1
  ]
end


to flag-intra-group-informal
  ;; Intra-group informal
  ;; Agents in the same group may interact
  ;; cycling through groups by asking point persons instead of using a counter
  ask point-persons [
    ;; check to see if point person is flagged
    let chance4 ( ( random 100 ) + 1 )
    if chance4 <= ( (Probability-intra-group-informal-meetings * 2)/ 18 ) [
      set updating? true
    ]
    ;; check to see if advisors are flagged
    ask advisors with [ group = [ group ] of myself ] [
      set chance4 ( ( random 100 ) + 1 )
      ;; rolling the dice to see if the advisor will be flagged
      if chance4 <= ( ( Probability-intra-group-informal-meetings * 2) / 18 ) [
        set updating? true
      ]
    ]
    ;; if more than 2 agents flagged, otherwise reset flagging data
    ifelse count turtles with [ updating? = true ] > 1
      [
        set type-of-interaction "Intra-group Informal"
        interact ]
      [
        set sum-flagged ( sum-flagged + ( count turtles with [ updating? = true ] ) )
        ask turtles with [ updating? = true ] [ set updating? false ]
      ]
  ]
end


;; what happens during an interaction. there are several phases
to interact
  ;; updating tracking variables first
  set total-number-of-interactions total-number-of-interactions + 1
  ask turtles with [ updating? = true ] [ set number-of-times-interacting number-of-times-interacting + 1 ]
  set sum-number-of-times-interacting sum [ number-of-times-interacting ] of turtles
  set average-interactions-per-agent (sum-number-of-times-interacting / Total-Number-of-Agents)
  set sum-flagged ( sum-flagged + ( count turtles with [ updating? = true ] ) )
  ;; normalize respect values for agents that are part of interaction
  normalize-respect
  ;; update individual-positions weighted by respect
  update-position
  ;; show interacting agents and patches differently to make them stand out and update their labels
  do-colors
  update-display
  ;; if cost of dissent is activated and it is one of the final 20 days in the run, then check for cost of dissent
  if Cost-of-Dissent-possible? and ticks > 44 [ cost-of-dissent ]
  ;; reset updating flags and normalized respect variables
  reset
  ;; wait for time set by a slider so that it is possible to view changes more slowly
  wait wait-time
  ;; reset the colors and labels of patches and agents
  do-colors
  update-display
end


;; this procedure allows to normalize the respect values in setup
;; in order for the math to work properly with teh matrix multiplication, the respect scores each agent has for the other agents with which it is interacting and itself need to add up to 1.
to normalize-respect
  
  ask turtles with [ updating? = true ] [
    
    ;; calculating the sum of the respect of the patches that will be used in the update individual-position procedure
    let respect-sum 0
    
    ;; asking patches corresponding to agents interacting with to add their respect value to the respect-sum
    ask patches with [ pycor = [ycor] of myself ] [
      if any? turtles with [ id = [ pxcor ] of myself and updating? = true] [ set respect-sum ( respect-sum + respect ) ]
    ]

    ;; now, the patches corresponging to agents interacting with divide the respect score by the respect-sum and sate it as the normalized respect
    ask patches with [ pycor = [ycor] of myself ] [
      if any? turtles with [ id = [ pxcor ] of myself and updating? = true] [
        set normalized-respect ( respect / respect-sum )
      ]
    ]
  ]
end


;;this procedure updates the individual-position for a conservation practice
;; agent�s individual-position values are updated by calculating an average of the individual-positions of all agents it is interacting with including itself, weighted by the respect that each agent has for each other
to update-position
  ;; asking turtles that are updating
  ask turtles with [ updating? = true ] [
    ;;initialize local variables
    let weighted-position 0
    let my-ycor ycor
    ;;each turtle needs to ask each patch in its row (defined by the ycor), to multiply its stored value of respect by
    ;;the individual-position value stored by the turtle whose ID is defined by the xcor of the patch
    ask patches with [ pycor = my-ycor and normalized-respect != 0 ] [
      ;; initializing more local variables
      let pxcor-here abs ( pxcor )
      let position-multiplier 0
      ;; asking the 1 turtle that is in the row with the patch to set variables (to store its individual-position)
      ask turtles with [ ID = pxcor-here ] [
        set position-multiplier individual-position
      ]
      ;; calculating the new individual-position
      set weighted-position ( weighted-position + ( normalized-respect * position-multiplier ) )
    ]
    ;; storing the final weighted-position in the buffer layer
    set position-future weighted-position
  ]
  ;; setting the individual-position as the position-future-future after all calculations of position-future done
  ask turtles with [ updating? = true ] [
    set individual-position position-future
  ]
end


;; reset updating flags and normalized respect variables
to reset
  ask turtles with [ updating? = true ] [
    set updating? false
  ]
  ask patches with [ normalized-respect != 0 ] [
    set normalized-respect 0
  ]
  
end


;; labels for agents and patches. There are qualifiers for the ask patches since this is not being called by the observer in some cases.
to update-display
  ask patches with [ normalized-respect != 0 ] [ set plabel precision normalized-respect 3 ]
  ask patches with [ normalized-respect = 0 ] [ set plabel precision normalized-respect 3 ]
  ask turtles with [ updating? = true ] [ set label precision individual-position 3 ]
  ask turtles with [ updating? = false ] [ set label precision individual-position 3 ]
end



;; sees if agents who have just interacted are far from the collective (mean) individual-position of the local group and if so reduces their self respect
;; CoD only applies during the last 20 days and its effect increases as the end nears 
to cost-of-dissent
  if count turtles with [ updating? ] > 2 [
    ;; ask the agents that just updated
    ask turtles with [ updating? ] [
      let ID-CoD ID
      ;;determine the collective position of the local group it just interacted with, excluding itself
      set local-group-collective-position mean [ individual-position ] of turtles with [ updating? and ID != ID-CoD ]
      ;; determine the spread of individual individual-positions of this local group
      set local-group-SD standard-deviation [ individual-position ] of turtles with [ updating? and ID != ID-CoD ]
      ;; if the difference between the agent's individual-position and the local group's individual-position is greater than 1 standard deviation, then it is subject to cost of dissent
      if ( abs ( individual-position - local-group-collective-position ) ) > local-group-SD [
        ;; determining how far into the CoD period it is
        let dissent-period maximum-iterations - 44
        let dissent-timer ticks - 44
        ;; converts it into a % of the how advanced the CoD period is, where day 64 = 100%
        let dissent-respect-scale dissent-timer / dissent-period
        ;; multiplies this amount by the base possible reduction in self respect due to CoD. e.g. an advisor subject to CoD on day 64 would reduce its self respect by 1 (but self-respect never goes negative, 0 is minimum)
        let scaled-self-respect-reduction-amount Self-respect-reduction-CoD * dissent-respect-scale
        let respect-here [ respect ] of patch-here
        ;; reduces the self respect now by this amount and sets a minimum for mathematical purposes
        let new-self-respect respect-here - scaled-self-respect-reduction-amount
        if new-self-respect < .0001 [ set new-self-respect .0001 ] ;;; minimum needed only here so that multiple agents with 0 respect don't interact, which creates a division by 0 error.
        ;; and here, if an agent subject to CoD it is no longer counted as entrenched.
        set entrenched? false
        ask patch-here [ set respect new-self-respect ]
        set count-subject-to-CoD count-subject-to-CoD + 1
      ]
    ]
  ]
end


to do-plots-and-globals
  ;; Setting this display-related variable to be blank, since there are no interactions happening.
  set type-of-interaction " "
  ;; tracking metrics
  set collective-position mean [ individual-position ] of turtles
  set Spread-of-individual-positions standard-deviation [ individual-position ] of turtles 
  
  ;; doing plots
  
  set-current-plot "Collective Position"
  set-current-plot-pen "All Agents"
  plot collective-position

  set-current-plot-pen "Point Persons"
  plot mean [ individual-position ] of point-persons
  
  set-current-plot "Individual Positions Colored by Group"
  let turtle-count 0
  foreach sort turtles [
    ask ? [
      set-current-plot-pen word "" turtle-count
      
      ifelse entrenched? [
        set-plot-pen-color green
      ]
      [
        set-plot-pen-color inactive-color - 2
      ]
      plot individual-position
      set turtle-count turtle-count + 1
      
    ]
  ]
  
  set-current-plot "Respect Histogram"
  set-current-plot-pen "default"
  set-plot-pen-mode 1
  set-histogram-num-bars 15
  histogram [ respect ] of patches with [ pxcor != ( abs ( pycor ) ) ]
  
  set-current-plot "Individual Position Histogram"
  set-current-plot-pen "default"
  set-plot-pen-mode 1
  set-histogram-num-bars 5
  histogram [ individual-position ] of turtles
  
  set-current-plot "Number of Interactions"
  set-current-plot-pen "Total Number of Interactions"
  plot total-number-of-interactions
  set-current-plot-pen "Sum of Times Agents Involved in Interactions"
  plot sum-number-of-times-interacting
  set-current-plot-pen "Number of Times Agents Flagged to Interact"
  plot sum-flagged
  ;set-current-plot-pen "Average Number of Interactions"
  ;plot
  
  set-current-plot "Spread of individual positions"
  set-current-plot-pen "Standard Deviation"
  plot Spread-of-individual-positions
  
  let DM-count 0
  set-current-plot "Spread of individual positions by Group"
  foreach sort point-persons [
    ask ? [
      set-current-plot-pen word "default" DM-count
      set-plot-pen-color inactive-color - 2
      if count  turtles with [ group = [ group ] of myself ] > 1 [
        plot ( standard-deviation [ individual-position ] of turtles with [ group = [ group ] of myself ] )
      ]
      set DM-count DM-count + 1
    ]
  ]
  
  let DM-count1 0
  set-current-plot "Collective Position by Group"
  foreach sort point-persons [
    ask ? [
      set-current-plot-pen word "default" DM-count1
      set-plot-pen-color inactive-color - 2
      plot ( mean [ individual-position ] of turtles with [ group = [ group ] of myself ] )
      set DM-count1 DM-count1 + 1
    ]
  ]    
  
  set-current-plot "Spread of Individual Positions by Group"
  foreach sort point-persons [
    ask ? [
      set-current-plot-pen word "default" DM-count
      set-plot-pen-color inactive-color - 2
      if count  turtles with [ group = [ group ] of myself ] > 1 [
        plot ( standard-deviation [ individual-position ] of turtles with [ group = [ group ] of myself ] )
      ]
      set DM-count DM-count + 1
    ]
  ]
 
end
@#$#@#$#@
GRAPHICS-WINDOW
651
10
1237
617
-1
-1
32.0
1
10
1
1
1
0
0
0
1
0
17
-17
0
0
0
1
ticks
30.0

BUTTON
516
304
579
337
NIL
Go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
516
265
580
298
NIL
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
516
342
610
375
Go Forever
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
875
813
1207
963
Collective Position
Time
Position
0.0
64.0
0.0
1.0
false
true
"" ""
PENS
"All Agents" 1.0 0 -16777216 true "" ""
"Point Persons" 1.0 0 -2674135 true "" ""

SLIDER
13
34
191
67
Total-Number-of-Agents
Total-Number-of-Agents
6
18
18
1
1
NIL
HORIZONTAL

PLOT
601
968
868
1241
Individual Positions Colored by Group
Time
Position
0.0
64.0
0.0
1.0
false
false
"" ""
PENS
"0" 1.0 0 -16777216 true "" ""
"1" 1.0 0 -16777216 true "" ""
"2" 1.0 0 -16777216 true "" ""
"3" 1.0 0 -16777216 true "" ""
"4" 1.0 0 -16777216 true "" ""
"5" 1.0 0 -16777216 true "" ""
"6" 1.0 0 -16777216 true "" ""
"7" 1.0 0 -16777216 true "" ""
"8" 1.0 0 -16777216 true "" ""
"9" 1.0 0 -16777216 true "" ""
"10" 1.0 0 -16777216 true "" ""
"11" 1.0 0 -16777216 true "" ""
"12" 1.0 0 -16777216 true "" ""
"13" 1.0 0 -16777216 true "" ""
"14" 1.0 0 -16777216 true "" ""
"15" 1.0 0 -16777216 true "" ""
"16" 1.0 0 -16777216 true "" ""
"17" 1.0 0 -16777216 true "" ""
"18" 1.0 0 -16777216 true "" ""
"19" 1.0 0 -16777216 true "" ""

PLOT
12
882
212
1008
Respect Histogram
Respect Value
Occurances
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
222
882
421
1009
Individual Position Histogram
Position Value
Occurances
0.0
1.001
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
12
404
235
437
Probability-of-mutation
Probability-of-mutation
0
10
10
1
1
per 1000
HORIZONTAL

MONITOR
21
597
226
658
Final Decision
final-decision
17
1
15

MONITOR
231
597
372
642
Number of Mutations
number-of-mutations
17
1
11

TEXTBOX
24
162
220
185
Position Setup
13
15.0
1

MONITOR
21
507
188
568
Collective Position
precision collective-position 3
17
1
15

SLIDER
264
283
436
316
Wait-time
Wait-time
0
5
0.5
.5
1
Seconds
HORIZONTAL

TEXTBOX
261
37
411
55
Inter-group Interactions
11
0.0
1

TEXTBOX
263
136
413
154
Intra-group Interactions
11
0.0
1

SLIDER
256
190
536
223
Probability-intra-group-informal-meetings
Probability-intra-group-informal-meetings
0
100
100
2
1
%
HORIZONTAL

SLIDER
13
71
171
104
Total-Number-of-Groups
Total-Number-of-Groups
1
3
3
1
1
NIL
HORIZONTAL

PLOT
13
1015
519
1198
Number of Interactions
Time
Occurances
0.0
64.0
0.0
300.0
false
true
"" ""
PENS
"Total Number of Interactions" 1.0 0 -16777216 true "" ""
"Sum of Times Agents Involved in Interactions" 1.0 0 -2674135 true "" ""
"Number of Times Agents Flagged to Interact" 1.0 0 -11221820 true "" ""

PLOT
601
661
869
811
Spread of Individual Positions
Time
Spread
0.0
64.0
0.0
0.4
false
false
"" ""
PENS
"Standard Deviation" 1.0 0 -16777216 true "" ""

PLOT
601
814
869
964
Spread of Individual Positions by Group
Time
Spread
0.0
64.0
0.0
0.4
false
false
"" ""
PENS
"default0" 1.0 0 -16777216 true "" ""
"default1" 1.0 0 -16777216 true "" ""
"default2" 1.0 0 -16777216 true "" ""
"default3" 1.0 0 -16777216 true "" ""
"default4" 1.0 0 -16777216 true "" ""
"default5" 1.0 0 -16777216 true "" ""
"default6" 1.0 0 -16777216 true "" ""
"default7" 1.0 0 -16777216 true "" ""
"default8" 1.0 0 -16777216 true "" ""
"default9" 1.0 0 -16777216 true "" ""

TEXTBOX
268
264
498
283
Visualization
13
15.0
1

PLOT
878
686
1125
811
Collective Position by Group
Time
Position
0.0
64.0
0.0
1.0
false
false
"" ""
PENS
"default0" 1.0 0 -16777216 true "" ""
"default1" 1.0 0 -16777216 true "" ""
"default2" 1.0 0 -16777216 true "" ""
"default3" 1.0 0 -16777216 true "" ""
"default4" 1.0 0 -16777216 true "" ""
"default5" 1.0 0 -16777216 true "" ""
"default6" 1.0 0 -16777216 true "" ""

CHOOSER
13
107
174
152
Group-agent-distribution
Group-agent-distribution
"equal-size-groups" "random-size"
0

CHOOSER
11
182
173
227
Position-distribution
Position-distribution
"random-uniform" "intra-group-polarization" "inter-group-polarization"
0

SLIDER
256
155
522
188
Frequency-of-intra-group-formal-meetings
Frequency-of-intra-group-formal-meetings
0
65
20
1
1
NIL
HORIZONTAL

SLIDER
257
53
522
86
Frequency-of-inter-group-formal-meetings
Frequency-of-inter-group-formal-meetings
0
65
20
1
1
NIL
HORIZONTAL

SLIDER
257
88
524
121
Probability-inter-group-informal-meetings
Probability-inter-group-informal-meetings
0
100
20
1
1
%
HORIZONTAL

SLIDER
10
258
241
291
Point-person-position-difference-PPC
Point-person-position-difference-PPC
.01
.5
0.2
.01
1
NIL
HORIZONTAL

MONITOR
232
698
458
743
Number of agents entrenched at start
count-entrenched-at-start
17
1
11

MONITOR
232
751
567
796
Number of agents who became entrenched after mutation
count-entrenched-after-mutation
17
1
11

SWITCH
13
327
188
360
Entrenchment-possible?
Entrenchment-possible?
1
1
-1000

SWITCH
13
368
189
401
Cost-of-dissent-possible?
Cost-of-dissent-possible?
1
1
-1000

MONITOR
232
647
571
692
Count of times agents subject to cost of dissent pressure
count-subject-to-CoD
17
1
11

TEXTBOX
21
10
181
42
Organizational Parameters
13
15.0
1

TEXTBOX
18
303
174
335
Psychological Parameters
13
15.0
1

MONITOR
190
507
377
568
Decision Strategy
decision-strategy-used
17
1
15

TEXTBOX
250
480
400
501
Primary Metrics
15
85.0
1

MONITOR
381
507
613
568
Spread of Iindividual Positions
Spread-of-individual-positions
17
1
15

TEXTBOX
248
575
398
594
Other Metrics
15
85.0
1

MONITOR
264
321
504
382
Type of Interaction Occuring Now
type-of-interaction
17
1
15

TEXTBOX
300
387
504
415
Interacting agents highlighted at right
11
0.0
1

TEXTBOX
808
628
958
647
Metrics Over Time
15
85.0
1

TEXTBOX
178
844
393
870
Other Data
16
85.0
1

TEXTBOX
22
238
172
256
Decision Parameters
13
15.0
1

TEXTBOX
261
10
411
28
Interaction Parameters
13
15.0
1

@#$#@#$#@
CoDMER Version 1.01 December 2012
    

(C)2012 Board of Trustees of the University of Illinois
    

Lead Author: Moira Zellner, University of Illinois at Chicago

Please refer to the overview of the model that is available to download along with this NetLogo file at www.openabm.org to see the full table and figures referred to in the text below.

## 1.  PURPOSE

We present here a general description of the CoDMER (Collective Decision Making for Ecological Restoration) model. This model can be used to investigate how structural and behavioral factors can influence collective decision making processes and outcomes in the context of ecological restoration. It is informed by existing literature on collective decision making and empirical data from the Chicago Wilderness region.

The model represents one planning season for the organization. One iteration represents one work day and the planning season is 64 workdays (3 months where there are 5 workdays per week), during which agents (advisors and point persons) interact with selected others, and update their position with respect to a restoration decision based on how they are influenced by the other agents. At the end of the season, they reach a collective decision, based on how close they are in their positions. 

There are two versions of the model. The base version only explores the effects of structural aspects of collective decision making, like the number and size of groups, the occurrence of mutation (changes in external information), and the frequency of interaction within and across groups. The complex model adds the entrenchment and cost of dissent mechanisms to the base model. 

For more details, please refer to Watkins, C., Massey, D., Brooks, J., Ross, K., Zellner, M. L. (in review). "Understanding the mechanisms of collective decision-making in ecological restoration: An agent-based model of actors and organizations." Ecology and Society. 

## 2. HOW IT WORKS

Prior to initialization, define a scenario by setting parameter values in the sliders and choosers in the interface: 

a. Organizational Parameters

- Total-Number-of-Agents: This shows the total number of agents in the modeled organization. We recommend using 18 to start and using a number that is evenly divisible by the number of groups.

- Total-Number-of-Groups: The total number of groups in the modeled organization. 1, 2, or 3 can be selected.

- Group-agent-distribution: Refers to how agents are distributed between the groups. We recommend using equal-sized groups only.

b. Position Setup

- Position-distribution: This controls how agents set up their individual position value. The default setting is random (uniform), but two polarization settings are available. Intra-group polarization is when half of the agents in each group have a position value of 0 and the other half have a value of 1. Inter-group polarization can be used with 2 groups only; all of the agents in one group have a position value of 0 and the all the agents in the other group have a position value of 1.

c. Decision Parameters

- Point-person-position-difference-PPC: The maximum difference between the point person positions for the resulting decision strategy to be point-person consensus; otherwise the outcome will be outside arbiter. 
	    
d. Psychological Parameters

- Entrenchment-possible?: If toggled, entrenchment can happen during the setup of position values or after a mutation. Default setting is off.

- Cost-of-dissent-possible?: If toggled, agents may be subject to cost of dissent pressures to conform to the rest of the group after T = 44. Default setting is off.

- Probability-of-mutation: The probability of each agent receiving new external information each time step. Default setting is off.

e. Interaction Parameters

- Frequency-of-inter-group-formal-meetings: Frequency of inter-group formal meetings, regular meetings with all point persons. Default setting is 20, meaning once a month. A setting of 0 would indicate meetings never take place.

- Probability-inter-group-informal-meetings: Probability that each agent will be selected for this type of interaction each time step; at least two agents from different groups need to be selected for meeting to take place. Default setting is 20%, which translates to roughly one of these meetings per week.

- Frequency-of-intra-group-formal-meetings: How often intra-group formal meetings, regular meetings with all agents in the same group, takee place. Default setting is 20, meaning once a month. A setting of 0 would indicate meetings never take place.

- Probability-intra-group-informal-meetings: Probability that each agent will be selected for this type of interaction each time step; at least two agents need to be selected for a meeting to happen. Default setting is 100%, which translates to roughly one of these meetings per day.

f. Visualization

- wait-time: How many seconds the model waits during an interaction to allow the user to see what is happening before moving on to the next interaction. Default setting is 1. The model runs very quickly with a 0 setting so the user will see just flashes.

Once a scenario is defined with the above parameters, click the setup button to initialize the model. Agents are placed so there is one agent per row and column. Respect scores stored in cells, where the score indicates the respect the agent in the row has for the agent in the column. Respect scores are displayed on the cells and position scores on the agents.

After initialization, click the go button to run the simulation for one step, or the go forever button to run the entire simulation. During a simulation, interacting agents and their respective cells are highlighted on the landscape.

## 3. THINGS TO OBSERVE

There are a number of different ways to experiment with the model. In the base model (without cost of dissent and entrenchment), try the following:

1. With no mutation, test the difference between having 1, 2 or 3 groups in collective positions and spread across agents, and final decision strategy.

2. Turn off and on the various types of interactions. Please note that you must have at least 2 groups to adequately compare the effects across scenarios. In addition to collective preference and spread across agents, look at the variation of positions over time. Do certain types of meetings help convergence more than others?

3. Experiment with different mutation rates. Does mutation have a large impact on the spread of individual positions? Look at the time series of individual positions over the course of a run and notice what happens after a large mutation occurs. 

4. Do either of the polarization options (under position setup) have a big impact? What  causes the agents to come together after being polarized? 

5. The starting collective position is always 0.5. Did anything you tried in any these base model tests change the collective position around this initial value?

The complex model can be set up toggling cost of dissent (CoD) and entrenchment, separately and together.

6. How different are the time series graphs with the complex model than with the base model? 

7. Does the collective position seem to change more with the complex model? If so, why?

## 4. HOW TO CITE

Zellner, M. L. 2012. CoDMER: Collective Decision Making for Ecological Restoration. Department of Urban Planning and Policy. University of Illinois at Chicago.

## 5. REFERENCES

Watkins, C., Massey, D., Brooks, J., Ross, K., Zellner, M. L. (in review). "Understanding the mechanisms of collective decision-making in ecological restoration: An agent-based model of actors and organizations." Ecology and Society.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="pref-outliers" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean-preference</metric>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform-outlier-respected&quot;"/>
      <value value="&quot;random-uniform-outlier-not-respected&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="pref-outliers-2groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean-preference</metric>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform-outlier-respected&quot;"/>
      <value value="&quot;random-uniform-outlier-not-respected&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="30" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;15-1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <metric>sum-flagged</metric>
    <metric>sum-number-of-times-interacting</metric>
    <metric>average-interactions-per-agent</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
      <value value="&quot;14-2&quot;"/>
      <value value="&quot;15-1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Mutations" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <metric>sum-flagged</metric>
    <metric>sum-number-of-times-interacting</metric>
    <metric>average-interactions-per-agent</metric>
    <metric>mean-preference-change</metric>
    <metric>total-individual-preference-change</metric>
    <metric>number-of-mutations</metric>
    <metric>total-big-mutations</metric>
    <metric>total-flipped-mutations</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outliers" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <metric>sum-flagged</metric>
    <metric>sum-number-of-times-interacting</metric>
    <metric>average-interactions-per-agent</metric>
    <metric>mean-preference-change</metric>
    <metric>total-individual-preference-change</metric>
    <metric>number-of-mutations</metric>
    <metric>total-big-mutations</metric>
    <metric>total-flipped-mutations</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform-outlier-respected&quot;"/>
      <value value="&quot;random-uniform-outlier-not-respected&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base for Comparison" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <metric>sum-flagged</metric>
    <metric>sum-number-of-times-interacting</metric>
    <metric>average-interactions-per-agent</metric>
    <metric>mean-preference-change</metric>
    <metric>total-individual-preference-change</metric>
    <metric>number-of-mutations</metric>
    <metric>total-big-mutations</metric>
    <metric>total-flipped-mutations</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base for Comparison-nolimit" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <metric>sum-flagged</metric>
    <metric>sum-number-of-times-interacting</metric>
    <metric>average-interactions-per-agent</metric>
    <metric>mean-preference-change</metric>
    <metric>total-individual-preference-change</metric>
    <metric>number-of-mutations</metric>
    <metric>total-big-mutations</metric>
    <metric>total-flipped-mutations</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Meetings-Formal" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;One-roll-per-tick-one-agent-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Meetings-Formal-notimelimit" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;One-roll-per-tick-one-agent-only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Polarization" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
      <value value="&quot;polarized&quot;"/>
      <value value="&quot;polarized-within-groups&quot;"/>
      <value value="&quot;polarized-between-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Polarization-nolimits" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
      <value value="&quot;polarized&quot;"/>
      <value value="&quot;polarized-within-groups&quot;"/>
      <value value="&quot;polarized-between-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="time-respect-update" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;based-on-preference&quot;"/>
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="mutation-respect-update" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;based-on-preference&quot;"/>
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="polarized-respect-update" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;based-on-preference&quot;"/>
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;polarized&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="outlier-respect" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;high-respect-outliers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outlier-respect-level" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.0010"/>
      <value value="0.01"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;high-respect-outliers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outlier-respect-level2" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.06"/>
      <value value="0.16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;high-respect-outliers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outlier-respect-level4" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
      <value value="0.15"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;high-respect-outliers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outlier-respect-level5" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-to-reach-consensus</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.25"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;high-respect-outliers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="NewvsOld" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-new-test&quot;"/>
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PP-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="closeness-of-voters" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision</metric>
    <metric>final-decision-explained</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Old-Method?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Max-respect-for-others">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.01"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="respect-for-others" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision</metric>
    <metric>final-decision-explained</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Old-Method?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Max-respect-for-others" first="0.1" step="0.1" last="0.9"/>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Old-New" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision</metric>
    <metric>final-decision-explained</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Old-Method?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Max-respect-for-others">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Mutation-Old-New" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision</metric>
    <metric>final-decision-explained</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Old-Method?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
      <value value="3"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Max-respect-for-others">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outliers-how-much-respect-needed" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision</metric>
    <metric>final-decision-explained</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Old-Method?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;high-respect-outliers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Max-respect-for-others">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outliers-control-random" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision</metric>
    <metric>final-decision-explained</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Old-Method?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Max-respect-for-others">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Outliers-.01" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision</metric>
    <metric>final-decision-explained</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Old-Method?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;high-respect-outliers&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Max-respect-for-others">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.01"/>
      <value value="0.0010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.6-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test-entrenchment-yes-no" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>final-decision</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base-self-respect-reduction">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test-CoD-base" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>final-decision</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base-self-respect-reduction">
      <value value="0.2"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="test-CoD-base-with-entrenchment" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>final-decision</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base-self-respect-reduction">
      <value value="0.2"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="mutation-rate-test" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="mutation-rate-test1000" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="mutation-rate-number" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>number-of-mutations</metric>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
      <value value="11"/>
      <value value="12"/>
      <value value="20"/>
      <value value="30"/>
      <value value="40"/>
      <value value="50"/>
      <value value="60"/>
      <value value="70"/>
      <value value="80"/>
      <value value="90"/>
      <value value="100"/>
      <value value="150"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="New-Base-CoD-Entrenchment" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="New-polarization" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
      <value value="&quot;polarized&quot;"/>
      <value value="&quot;polarized-within-groups&quot;"/>
      <value value="&quot;polarized-between-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Number-Agents-groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Number-of-Agents" first="3" step="1" last="20"/>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutation" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-cod-entrench-5m" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-cod-entrench-10m" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-cod-entrench-1group" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="base-polarized" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
      <value value="&quot;polarized&quot;"/>
      <value value="&quot;polarized-within-groups&quot;"/>
      <value value="&quot;polarized-between-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-polarized" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
      <value value="&quot;polarized&quot;"/>
      <value value="&quot;polarized-within-groups&quot;"/>
      <value value="&quot;polarized-between-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Number-Agents-groups-Number-Interactions" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Number-of-Agents" first="3" step="1" last="20"/>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="base-polarized-within" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;polarized-within-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="base-polarized-between" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;polarized-between-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-polarized-within" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;polarized-within-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-polarized-between" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;polarized-between-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Complex-Number-Agents-groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Number-of-Agents" first="3" step="1" last="20"/>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Number-Agents-groups-Number-All-Measures" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Number-of-Agents" first="3" step="1" last="18"/>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-cod-entrench-Outlier" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform-outlier-high-self-respect&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-normal.5-outlier&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-0-1000" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Probability-of-mutation" first="0" step="5" last="1000"/>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-0-100-1group" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Probability-of-mutation" first="0" step="5" last="100"/>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-0-100-2groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Probability-of-mutation" first="0" step="5" last="100"/>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-0-100-3groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Probability-of-mutation" first="0" step="5" last="100"/>
    <enumeratedValueSet variable="number-of-groups">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-200-1000-1group" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Probability-of-mutation" first="200" step="100" last="1000"/>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-200-1000-2groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Probability-of-mutation" first="200" step="100" last="1000"/>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-200-1000-3groups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <steppedValueSet variable="Probability-of-mutation" first="200" step="100" last="1000"/>
    <enumeratedValueSet variable="number-of-groups">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Mutations-150-allgroups" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Meetings-Scenario1" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Meetings-Scenario2" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Meetings-Scenario3" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Meetings-Scenario4" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Base-Meetings-Scenario5" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="complex-cod-entrench" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>final-decision-explained</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-random</metric>
    <metric>decision-mean</metric>
    <metric>decision-consensus</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>mean-preference</metric>
    <metric>stan-dev-all</metric>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>number-of-mutations</metric>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-group-meeting?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-point-person-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenched-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="high-self-respect?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-distribution">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-spontaneous-exchange">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="respect-based-on-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-Preference-Outliers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-preference-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="update-normalized-respect-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Outlier-respect-for-others">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-Dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-spontaneous">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="setup-output?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mutation-Method">
      <value value="&quot;Each-Agent-Decides&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="voter-closeness" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="preference-precision" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="voter-closeness-complex" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="preference-precision-complex" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="preference-precision-rev" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="preference-precision-complex-rev" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.15"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="preference-precision-rev---2" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="preference-precision-complex-rev-----2" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-precision">
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
      <value value="0.04"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="preference-precision-rev---done" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="preference-precision" first="0.0030" step="0.0030" last="0.35"/>
  </experiment>
  <experiment name="preference-precision-complex-rev-----done" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>decision-strategy-used</metric>
    <metric>number-of-mutations</metric>
    <metric>decision-OA</metric>
    <metric>decision-PPC</metric>
    <metric>decision-WGC</metric>
    <metric>count-entrenched-at-start</metric>
    <metric>count-entrenched-after-mutation</metric>
    <metric>count-subject-to-CoD</metric>
    <metric>final-decision</metric>
    <metric>final-tick</metric>
    <metric>collective-preference</metric>
    <metric>Spread-of-individual-preferences</metric>
    <metric>total-number-of-interactions</metric>
    <enumeratedValueSet variable="Number-of-Agents">
      <value value="18"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-point-person-meetings">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Voter-preference-closeness">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-inter-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Formal-intra-group-meetings?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Entrenchment-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Cost-of-dissent-possible?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Time-between-group-meeting">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-setup">
      <value value="&quot;equal-size-groups&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Number-of-groups">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wait-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-intra-group-informal">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="preference-setup">
      <value value="&quot;random-uniform&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-inter-group-informal">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Probability-of-mutation">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="preference-precision" first="0.0030" step="0.0030" last="0.35"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
